summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--DOCS/man/en/input.rst5
-rw-r--r--player/command.c16
2 files changed, 12 insertions, 9 deletions
diff --git a/DOCS/man/en/input.rst b/DOCS/man/en/input.rst
index 8efa2ecedf..c1b1506d4c 100644
--- a/DOCS/man/en/input.rst
+++ b/DOCS/man/en/input.rst
@@ -616,9 +616,12 @@ an option at runtime.
Current MKV edition number. Setting this property to a different value will
restart playback. The number of the first edition is 0.
-``titles``
+``dvd-titles``
Number of DVD titles.
+``dvd-title``
+ Current DVD title number.
+
``chapters``
Number of chapters.
diff --git a/player/command.c b/player/command.c
index 4325d78a5a..1fa81d1b0d 100644
--- a/player/command.c
+++ b/player/command.c
@@ -436,9 +436,9 @@ static int mp_property_playtime_remaining(m_option_t *prop, int action,
return property_time(prop, action, arg, remaining / speed);
}
-/// Current title (RO)
-static int mp_property_title(m_option_t *prop, int action, void *arg,
- MPContext *mpctx)
+/// Current DVD title (RO)
+static int mp_property_dvd_title(m_option_t *prop, int action, void *arg,
+ MPContext *mpctx)
{
struct demuxer *demuxer = mpctx->master_demuxer;
if (!demuxer || !demuxer->stream)
@@ -722,9 +722,9 @@ static int mp_property_quvi_format(m_option_t *prop, int action, void *arg,
return mp_property_generic_option(prop, action, arg, mpctx);
}
-/// Number of titles in file
-static int mp_property_titles(m_option_t *prop, int action, void *arg,
- MPContext *mpctx)
+/// Number of titles in DVD
+static int mp_property_dvd_titles(m_option_t *prop, int action, void *arg,
+ MPContext *mpctx)
{
struct demuxer *demuxer = mpctx->master_demuxer;
unsigned int num_titles;
@@ -2118,12 +2118,12 @@ static const m_option_t mp_properties[] = {
M_OPT_MIN, 0, 0, NULL },
{ "time-remaining", mp_property_remaining, CONF_TYPE_TIME },
{ "playtime-remaining", mp_property_playtime_remaining, CONF_TYPE_TIME },
- { "title", mp_property_title, CONF_TYPE_INT, M_OPT_MIN, -1, 0, NULL },
+ { "dvd-title", mp_property_dvd_title, CONF_TYPE_INT, M_OPT_MIN, -1, 0, NULL },
{ "chapter", mp_property_chapter, CONF_TYPE_INT,
M_OPT_MIN, -1, 0, NULL },
M_OPTION_PROPERTY_CUSTOM("edition", mp_property_edition),
M_OPTION_PROPERTY_CUSTOM("quvi-format", mp_property_quvi_format),
- { "titles", mp_property_titles, CONF_TYPE_INT,
+ { "dvd-titles", mp_property_dvd_titles, CONF_TYPE_INT,
0, 0, 0, NULL },
{ "chapters", mp_property_chapters, CONF_TYPE_INT,
0, 0, 0, NULL },